@@ -1,7 +1,7 @@
 package Algorithm::AM;
 use strict;
 use warnings;
-our $VERSION = '3.05';
+our $VERSION = '3.06';
 # ABSTRACT: Classify data with Analogical Modeling
 use feature 'state';
 use Carp;
@@ -188,8 +188,9 @@ sub classify {
         my $class = $training_set->_index_for_class(
             $training_set->get_item($index)->class);
         if ( defined $self->{context_to_class}->{$context} ) {
-            $self->{context_to_class}->{$context} = 0
-              if $self->{context_to_class}->{$context} != $class;
+            if($self->{context_to_class}->{$context} != $class){
+                $self->{context_to_class}->{$context} = 0;
+            }
         }
         else {
             $self->{context_to_class}->{$context} = $class;
@@ -326,12 +327,12 @@ Algorithm::AM - Classify data with Analogical Modeling
 
 =head1 VERSION
 
-version 3.05
+version 3.06
 
 =head1 SYNOPSIS
 
  use Algorithm::AM;
- my $dataset = dataset_from_file('finnverb');
+ my $dataset = dataset_from_file(path => 'finnverb', format => 'nocommas');
  my $am = Algorithm::AM->new(training_set => $dataset);
  my $result = $am->classify($dataset->get_item(0));
  print @{ $result->winners };
@@ -342,7 +343,8 @@ version 3.05
 This module provides an object-oriented interface for
 classifying single items using the analogical modeling algorithm.
 To work with sets of items needing to be classified, see
-L<Algorithm::AM::Batch>.
+L<Algorithm::AM::Batch>. To run classification from the command line
+without writing your own Perl code, see L<analogize>.
 
 This module logs information using L<Log::Any>, so if you
 want automatic print-outs you need to set an adaptor. See the
@@ -534,7 +536,7 @@ L<https://github.com/garfieldnate/Algorithm-AM>
 
 =head1 AUTHOR
 
-Theron Stanford <shixilun@yahoo.com>, Nathan Glenn <garfieldnate@gmail.com>
+Theron Sanford <shixilun@yahoo.com>, Nathan Glenn <garfieldnate@gmail.com>
 
 =head1 CONTRIBUTORS
 
