@@ -1,7 +1,7 @@
 package Algorithm::AM::Batch;
 use strict;
 use warnings;
-our $VERSION = '3.05';
+our $VERSION = '3.06';
 # ABSTRACT: Classify items in batch mode
 use feature 'state';
 use Carp;
@@ -289,13 +289,12 @@ Algorithm::AM::Batch - Classify items in batch mode
 
 =head1 VERSION
 
-version 3.05
+version 3.06
 
 =head1 C<SYNOPSIS>
 
-  use Algorithm::AM;
   use Algorithm::AM::Batch;
-  my $dataset = dataset_from_file('finnverb');
+  my $dataset = dataset_from_file(path => 'finnverb', format => 'nocommas');
   my $batch = Algorithm::AM::Batch->new(
     training_set => $dataset,
     # print the result of each classification as they are provided
@@ -566,7 +565,7 @@ L<Algorithm::AM/classify>.
 
 =head1 AUTHOR
 
-Theron Stanford <shixilun@yahoo.com>, Nathan Glenn <garfieldnate@gmail.com>
+Theron Sanford <shixilun@yahoo.com>, Nathan Glenn <garfieldnate@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
