@@ -1,7 +1,7 @@
 package Algorithm::AM::DataSet;
 use strict;
 use warnings;
-our $VERSION = '3.05';
+our $VERSION = '3.06';
 # ABSTRACT: Manage data used by Algorithm::AM
 use Carp;
 use Algorithm::AM::DataSet::Item;
@@ -16,7 +16,7 @@ use Exporter::Easy (
 #pod  use Algorithm::AM::DataSet::Item 'new_item';
 #pod  my $dataset = Algorithm::AM::DataSet->new(cardinality => 10);
 #pod  # or
-#pod  $dataset = dataset_from_file('finnverb');
+#pod  $dataset = dataset_from_file(path => 'finnverb', format => 'nocommas');
 #pod  $dataset->add_item(
 #pod    new_item(features => [qw(a b c d e f g h i)]));
 #pod  my $item = $dataset->get_item(2);
@@ -354,7 +354,7 @@ Algorithm::AM::DataSet - Manage data used by Algorithm::AM
 
 =head1 VERSION
 
-version 3.05
+version 3.06
 
 =head1 SYNOPSIS
 
@@ -362,7 +362,7 @@ version 3.05
  use Algorithm::AM::DataSet::Item 'new_item';
  my $dataset = Algorithm::AM::DataSet->new(cardinality => 10);
  # or
- $dataset = dataset_from_file('finnverb');
+ $dataset = dataset_from_file(path => 'finnverb', format => 'nocommas');
  $dataset->add_item(
    new_item(features => [qw(a b c d e f g h i)]));
  my $item = $dataset->get_item(2);
@@ -451,7 +451,7 @@ mathematical basis.
 
 =head1 AUTHOR
 
-Theron Stanford <shixilun@yahoo.com>, Nathan Glenn <garfieldnate@gmail.com>
+Theron Sanford <shixilun@yahoo.com>, Nathan Glenn <garfieldnate@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
